@@ -25,6 +25,11 @@ urlpatterns = [
         views.DRFProductRetrieveView.as_view(),
         name="product_retrieve_original",
     ),
+    path(
+        "service/products/",
+        views.ProductListView.as_view(),
+        name="product_list_service",
+    ),
     path(
         "service/products/<int:pk>/",
         views.ProductRetrieveView.as_view(),
